==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Zurücksetzen des Systems, bitte warten...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Zurücksetzen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aktualisierungen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aktualisierungen fehlgeschlagen: Sie wurden unterbrochen.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aktualisierungen fehlgeschlagen: DPKG-Fehler.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aktualisierungen fehlgeschlagen: unzureichender Festplattenplatz.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Abbrechen und neu starten</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Zurücksetzen des Systems, bitte warten...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Zurücksetzen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aktualisierungen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aktualisierungen fehlgeschlagen: Sie wurden unterbrochen.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aktualisierungen fehlgeschlagen: DPKG-Fehler.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aktualisierungen fehlgeschlagen: unzureichender Festplattenplatz.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Abbrechen und neu starten</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
</TS>
